Package: cosmicsig
Title: Mutational Signatures from COSMIC (Catalogue of Somatic
        Mutations in Cancer)
Version: 1.3.1
Authors@R: 
    c(person(given = "Steven",
             family = "Rozen",
             role = c("aut", "cre"),
             email = "steverozen@pm.me",
             comment = c(ORCID = "0000-0002-4288-0056")),
      person(given = "Nanhai",
             family = "Jiang",
             role = "aut",
             comment = c(ORCID = "0000-0003-4974-2753")))
Description: A data package with 2 main package variables: 'signature' and 'etiology'. 
     The 'signature' variable contains the latest mutational signature profiles 
     released on COSMIC <https://cancer.sanger.ac.uk/signatures/> for 3 mutation
     types:
     * Single base substitutions in the context of preceding and following bases,
     * Doublet base substitutions, and
     * Small insertions and deletions.
    'cosmicsig' stands for COSMIC signatures. Please run ?'cosmicsig' for more
    information.
License: GPL-3
URL: https://github.com/Rozen-Lab/cosmicsig
BugReports: https://github.com/Rozen-Lab/cosmicsig/issues
Language: en-US
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
Depends: R (>= 3.5)
Suggests: testthat (>= 3.0.0), usethis
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-04-21 00:05:50 UTC; steve
Author: Steven Rozen [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4288-0056>),
  Nanhai Jiang [aut] (ORCID: <https://orcid.org/0000-0003-4974-2753>)
Maintainer: Steven Rozen <steverozen@pm.me>
Repository: CRAN
Date/Publication: 2026-04-21 05:20:02 UTC
Built: R 4.6.0; ; 2026-04-26 15:21:54 UTC; unix
