
<!-- README.md is generated from README.Rmd. Please edit that file -->

# cosmicsig

<!-- badges: start -->

[![R-CMD-check](https://github.com/Rozen-Lab/cosmicsig/workflows/R-CMD-check/badge.svg)](https://github.com/Rozen-Lab/cosmicsig/actions)
[![CRAN
status](https://www.r-pkg.org/badges/version/cosmicsig)](https://CRAN.R-project.org/package=cosmicsig)
[![License: GPL
v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
<!-- badges: end -->

## Purpose

Mutational signatures data from COSMIC, the Catalogue Of Somatic
Mutations In Cancer (<https://cancer.sanger.ac.uk/signatures/>). There
are also some helper functions for handling COSMIC signatures.

## Installation

### Get the stable version

``` r
install.packages("cosmicsig")
```

### Get the latest release

Install cosmicsig from [GitHub](https://github.com/):

``` r
if (!requireNamespace("remotes", quietly = TRUE)) {
  install.packages("remotes")
}
remotes::install_github(repo = "Rozen-Lab/cosmicsig", ref = "v1.3.0-branch")
```

## Reference manual

<https://github.com/Rozen-Lab/cosmicsig/blob/v1.3.0-branch/cosmicsig_1.3.0.pdf>
